[llvm] r217627 - Support: improve identify_magic to recognize COFF bigobj

Rui Ueyama ruiu at google.com
Thu Sep 11 14:09:58 PDT 2014


Author: ruiu
Date: Thu Sep 11 16:09:57 2014
New Revision: 217627

URL: http://llvm.org/viewvc/llvm-project?rev=217627&view=rev
Log:
Support: improve identify_magic to recognize COFF bigobj

identify_magic recognized a COFF bigobj as an import library file.
This patch fixes that.


Modified:
    llvm/trunk/lib/Support/Path.cpp
    llvm/trunk/unittests/Support/Path.cpp

Modified: llvm/trunk/lib/Support/Path.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Support/Path.cpp?rev=217627&r1=217626&r2=217627&view=diff
==============================================================================
--- llvm/trunk/unittests/Support/Path.cpp (original)
+++ llvm/trunk/unittests/Support/Path.cpp Thu Sep 11 16:09:57 2014
@@ -483,6 +483,8 @@ TEST_F(FileSystemTest, DirectoryIteratio
 const char archive[] = "!<arch>\x0A";
 const char bitcode[] = "\xde\xc0\x17\x0b";
 const char coff_object[] = "\x00\x00......";
+const char coff_bigobj[] = "\x00\x00\xff\xff........"
+    "\xc7\xa1\xba\xd1\xee\xba\xa9\x4b\xaf\x20\xfa\xf6\x6a\xa4\xdc\xb8";
 const char coff_import_library[] = "\x00\x00\xff\xff....";
 const char elf_relocatable[] = { 0x7f, 'E', 'L', 'F', 1, 2, 1, 0, 0,
                                  0,    0,   0,   0,   0, 0, 0, 0, 1 };
@@ -512,6 +514,7 @@ TEST_F(FileSystemTest, Magic) {
     DEFINE(archive),
     DEFINE(bitcode),
     DEFINE(coff_object),
+    { "coff_bigobj", coff_bigobj, sizeof(coff_bigobj), fs::file_magic::coff_object },
     DEFINE(coff_import_library),
     DEFINE(elf_relocatable),
     DEFINE(macho_universal_binary),





More information about the llvm-commits mailing list
--- llvm/trunk/lib/Support/Path.cpp (original)
+++ llvm/trunk/lib/Support/Path.cpp Thu Sep 11 16:09:57 2014
@@ -901,10 +901,16 @@ file_magic identify_magic(StringRef Magi
     return file_magic::unknown;
   switch ((unsigned char)Magic[0]) {
     case 0x00: {
       // COFF short import library file
       if (Magic[1] == (char)0x00 && Magic[2] == (char)0xff &&
-          Magic[3] == (char)0xff)
-        return file_magic::coff_import_library;
+          Magic[3] == (char)0xff) {
+         const char BigobjMagic[] =
+             "\xc7\xa1\xba\xd1\xee\xba\xa9\x4b\xaf\x20\xfa\xf6\x6a\xa4\xdc\xb8";
+         if (Magic.size() >= 28 &&
+             memcmp(Magic.data() + 12, BigobjMagic, sizeof(BigobjMagic)) == 0)
+           return file_magic::coff_object;
+         return file_magic::coff_import_library;
+      }
       // Windows resource file
       const char Expected[] = { 0, 0, 0, 0, '\x20', 0, 0, 0, '\xff' };
       if (Magic.size() >= sizeof(Expected) &&
@@ -901,10 +901,16 @@ file_magic identify_magic(StringRef Magi
   switch ((unsigned char)Magic[0]) {
     case 0x00: {
-      // COFF short import library file
+      // COFF bigobj or short import library file
       if (Magic[1] == (char)0x00 && Magic[2] == (char)0xff &&

Modified: llvm/trunk/unittests/Support/Path.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/unittests/Support/Path.cpp?rev=217627&r1=217626&r2=217627&view=diff
==============================================================================